==> vtk-8.1.1-1-x86_64.pkg.tar.xz: vtk/vtkLineRepresentation.java <==
// java wrapper for vtkLineRepresentation object
//

package vtk;
import vtk.*;

public class vtkLineRepresentation extends vtkWidgetRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void GetPoint1WorldPosition_2(double id0[]);
  public void GetPoint1WorldPosition(double id0[])
    { GetPoint1WorldPosition_2(id0); }

  private native double[] GetPoint1WorldPosition_3();
  public double[] GetPoint1WorldPosition()
    { return GetPoint1WorldPosition_3(); }

  private native void GetPoint1DisplayPosition_4(double id0[]);
  public void GetPoint1DisplayPosition(double id0[])
    { GetPoint1DisplayPosition_4(id0); }

  private native double[] GetPoint1DisplayPosition_5();
  public double[] GetPoint1DisplayPosition()
    { return GetPoint1DisplayPosition_5(); }

  private native void SetPoint1WorldPosition_6(double id0[]);
  public void SetPoint1WorldPosition(double id0[])
    { SetPoint1WorldPosition_6(id0); }

  private native void SetPoint1DisplayPosition_7(double id0[]);
  public void SetPoint1DisplayPosition(double id0[])
    { SetPoint1DisplayPosition_7(id0); }

  private native void GetPoint2DisplayPosition_8(double id0[]);
  public void GetPoint2DisplayPosition(double id0[])
    { GetPoint2DisplayPosition_8(id0); }

  private native double[] GetPoint2DisplayPosition_9();
  public double[] GetPoint2DisplayPosition()
    { return GetPoint2DisplayPosition_9(); }

  private native void GetPoint2WorldPosition_10(double id0[]);
  public void GetPoint2WorldPosition(double id0[])
    { GetPoint2WorldPosition_10(id0); }

  private native double[] GetPoint2WorldPosition_11();
  public double[] GetPoint2WorldPosition()
    { return GetPoint2WorldPosition_11(); }

  private native void SetPoint2WorldPosition_12(double id0[]);
  public void SetPoint2WorldPosition(double id0[])
    { SetPoint2WorldPosition_12(id0); }

  private native void SetPoint2DisplayPosition_13(double id0[]);
  public void SetPoint2DisplayPosition(double id0[])
    { SetPoint2DisplayPosition_13(id0); }

  private native void SetHandleRepresentation_14(vtkPointHandleRepresentation3D id0);
  public void SetHandleRepresentation(vtkPointHandleRepresentation3D id0)
    { SetHandleRepresentation_14(id0); }

  private native void InstantiateHandleRepresentation_15();
  public void InstantiateHandleRepresentation()
    { InstantiateHandleRepresentation_15(); }

  private native long GetPoint1Representation_16();
  public vtkPointHandleRepresentation3D GetPoint1Representation() {
    long temp = GetPoint1Representation_16();

    if (temp == 0) return null;
    return (vtkPointHandleRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPoint2Representation_17();
  public vtkPointHandleRepresentation3D GetPoint2Representation() {
    long temp = GetPoint2Representation_17();

    if (temp == 0) return null;
    return (vtkPointHandleRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLineHandleRepresentation_18();
  public vtkPointHandleRepresentation3D GetLineHandleRepresentation() {
    long temp = GetLineHandleRepresentation_18();

    if (temp == 0) return null;
    return (vtkPointHandleRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetEndPointProperty_19();
  public vtkProperty GetEndPointProperty() {
    long temp = GetEndPointProperty_19();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedEndPointProperty_20();
  public vtkProperty GetSelectedEndPointProperty() {
    long temp = GetSelectedEndPointProperty_20();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetEndPoint2Property_21();
  public vtkProperty GetEndPoint2Property() {
    long temp = GetEndPoint2Property_21();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedEndPoint2Property_22();
  public vtkProperty GetSelectedEndPoint2Property() {
    long temp = GetSelectedEndPoint2Property_22();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLineProperty_23();
  public vtkProperty GetLineProperty() {
    long temp = GetLineProperty_23();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedLineProperty_24();
  public vtkProperty GetSelectedLineProperty() {
    long temp = GetSelectedLineProperty_24();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTolerance_25(int id0);
  public void SetTolerance(int id0)
    { SetTolerance_25(id0); }

  private native int GetToleranceMinValue_26();
  public int GetToleranceMinValue()
    { return GetToleranceMinValue_26(); }

  private native int GetToleranceMaxValue_27();
  public int GetToleranceMaxValue()
    { return GetToleranceMaxValue_27(); }

  private native int GetTolerance_28();
  public int GetTolerance()
    { return GetTolerance_28(); }

  private native void SetResolution_29(int id0);
  public void SetResolution(int id0)
    { SetResolution_29(id0); }

  private native int GetResolution_30();
  public int GetResolution()
    { return GetResolution_30(); }

  private native void GetPolyData_31(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_31(id0); }

  private native void PlaceWidget_32(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_32(id0); }

  private native void BuildRepresentation_33();
  public void BuildRepresentation()
    { BuildRepresentation_33(); }

  private native int ComputeInteractionState_34(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_34(id0,id1,id2); }

  private native void StartWidgetInteraction_35(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_35(id0); }

  private native void WidgetInteraction_36(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_36(id0); }

  private native double[] GetBounds_37();
  public double[] GetBounds()
    { return GetBounds_37(); }

  private native void GetActors_38(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_38(id0); }

  private native void ReleaseGraphicsResources_39(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_39(id0); }

  private native int RenderOpaqueGeometry_40(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_40(id0); }

  private native int RenderTranslucentPolygonalGeometry_41(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_41(id0); }

  private native int HasTranslucentPolygonalGeometry_42();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_42(); }

  private native void SetInteractionState_43(int id0);
  public void SetInteractionState(int id0)
    { SetInteractionState_43(id0); }

  private native int GetInteractionStateMinValue_44();
  public int GetInteractionStateMinValue()
    { return GetInteractionStateMinValue_44(); }

  private native int GetInteractionStateMaxValue_45();
  public int GetInteractionStateMaxValue()
    { return GetInteractionStateMaxValue_45(); }

  private native void SetRepresentationState_46(int id0);
  public void SetRepresentationState(int id0)
    { SetRepresentationState_46(id0); }

  private native int GetRepresentationState_47();
  public int GetRepresentationState()
    { return GetRepresentationState_47(); }

  private native void SetDirectionalLine_48(boolean id0);
  public void SetDirectionalLine(boolean id0)
    { SetDirectionalLine_48(id0); }

  private native boolean GetDirectionalLine_49();
  public boolean GetDirectionalLine()
    { return GetDirectionalLine_49(); }

  private native void DirectionalLineOn_50();
  public void DirectionalLineOn()
    { DirectionalLineOn_50(); }

  private native void DirectionalLineOff_51();
  public void DirectionalLineOff()
    { DirectionalLineOff_51(); }

  private native int GetMTime_52();
  public int GetMTime()
    { return GetMTime_52(); }

  private native void SetRenderer_53(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_53(id0); }

  private native void SetDistanceAnnotationVisibility_54(int id0);
  public void SetDistanceAnnotationVisibility(int id0)
    { SetDistanceAnnotationVisibility_54(id0); }

  private native int GetDistanceAnnotationVisibility_55();
  public int GetDistanceAnnotationVisibility()
    { return GetDistanceAnnotationVisibility_55(); }

  private native void DistanceAnnotationVisibilityOn_56();
  public void DistanceAnnotationVisibilityOn()
    { DistanceAnnotationVisibilityOn_56(); }

  private native void DistanceAnnotationVisibilityOff_57();
  public void DistanceAnnotationVisibilityOff()
    { DistanceAnnotationVisibilityOff_57(); }

  private native void SetDistanceAnnotationFormat_58(String id0);
  public void SetDistanceAnnotationFormat(String id0)
    { SetDistanceAnnotationFormat_58(id0); }

  private native String GetDistanceAnnotationFormat_59();
  public String GetDistanceAnnotationFormat()
    { return GetDistanceAnnotationFormat_59(); }

  private native void SetDistanceAnnotationScale_60(double id0,double id1,double id2);
  public void SetDistanceAnnotationScale(double id0,double id1,double id2)
    { SetDistanceAnnotationScale_60(id0,id1,id2); }

  private native void SetDistanceAnnotationScale_61(double id0[]);
  public void SetDistanceAnnotationScale(double id0[])
    { SetDistanceAnnotationScale_61(id0); }

  private native double GetDistance_62();
  public double GetDistance()
    { return GetDistance_62(); }

  private native void SetLineColor_63(double id0,double id1,double id2);
  public void SetLineColor(double id0,double id1,double id2)
    { SetLineColor_63(id0,id1,id2); }

  private native long GetDistanceAnnotationProperty_64();
  public vtkProperty GetDistanceAnnotationProperty() {
    long temp = GetDistanceAnnotationProperty_64();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTextActor_65();
  public vtkFollower GetTextActor() {
    long temp = GetTextActor_65();

    if (temp == 0) return null;
    return (vtkFollower)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetRestrictFlag_66(int id0);
  public void SetRestrictFlag(int id0)
    { SetRestrictFlag_66(id0); }

  private native int GetRestrictFlagMinValue_67();
  public int GetRestrictFlagMinValue()
    { return GetRestrictFlagMinValue_67(); }

  private native int GetRestrictFlagMaxValue_68();
  public int GetRestrictFlagMaxValue()
    { return GetRestrictFlagMaxValue_68(); }

  public vtkLineRepresentation() { super(); }

  public vtkLineRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-5-x86_64.pkg.tar.xz: vtk/vtkLineRepresentation.java <==
// java wrapper for vtkLineRepresentation object
//

package vtk;
import vtk.*;

public class vtkLineRepresentation extends vtkWidgetRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void GetPoint1WorldPosition_2(double id0[]);
  public void GetPoint1WorldPosition(double id0[])
    { GetPoint1WorldPosition_2(id0); }

  private native double[] GetPoint1WorldPosition_3();
  public double[] GetPoint1WorldPosition()
    { return GetPoint1WorldPosition_3(); }

  private native void GetPoint1DisplayPosition_4(double id0[]);
  public void GetPoint1DisplayPosition(double id0[])
    { GetPoint1DisplayPosition_4(id0); }

  private native double[] GetPoint1DisplayPosition_5();
  public double[] GetPoint1DisplayPosition()
    { return GetPoint1DisplayPosition_5(); }

  private native void SetPoint1WorldPosition_6(double id0[]);
  public void SetPoint1WorldPosition(double id0[])
    { SetPoint1WorldPosition_6(id0); }

  private native void SetPoint1DisplayPosition_7(double id0[]);
  public void SetPoint1DisplayPosition(double id0[])
    { SetPoint1DisplayPosition_7(id0); }

  private native void GetPoint2DisplayPosition_8(double id0[]);
  public void GetPoint2DisplayPosition(double id0[])
    { GetPoint2DisplayPosition_8(id0); }

  private native double[] GetPoint2DisplayPosition_9();
  public double[] GetPoint2DisplayPosition()
    { return GetPoint2DisplayPosition_9(); }

  private native void GetPoint2WorldPosition_10(double id0[]);
  public void GetPoint2WorldPosition(double id0[])
    { GetPoint2WorldPosition_10(id0); }

  private native double[] GetPoint2WorldPosition_11();
  public double[] GetPoint2WorldPosition()
    { return GetPoint2WorldPosition_11(); }

  private native void SetPoint2WorldPosition_12(double id0[]);
  public void SetPoint2WorldPosition(double id0[])
    { SetPoint2WorldPosition_12(id0); }

  private native void SetPoint2DisplayPosition_13(double id0[]);
  public void SetPoint2DisplayPosition(double id0[])
    { SetPoint2DisplayPosition_13(id0); }

  private native void SetHandleRepresentation_14(vtkPointHandleRepresentation3D id0);
  public void SetHandleRepresentation(vtkPointHandleRepresentation3D id0)
    { SetHandleRepresentation_14(id0); }

  private native void InstantiateHandleRepresentation_15();
  public void InstantiateHandleRepresentation()
    { InstantiateHandleRepresentation_15(); }

  private native long GetPoint1Representation_16();
  public vtkPointHandleRepresentation3D GetPoint1Representation() {
    long temp = GetPoint1Representation_16();

    if (temp == 0) return null;
    return (vtkPointHandleRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPoint2Representation_17();
  public vtkPointHandleRepresentation3D GetPoint2Representation() {
    long temp = GetPoint2Representation_17();

    if (temp == 0) return null;
    return (vtkPointHandleRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLineHandleRepresentation_18();
  public vtkPointHandleRepresentation3D GetLineHandleRepresentation() {
    long temp = GetLineHandleRepresentation_18();

    if (temp == 0) return null;
    return (vtkPointHandleRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetEndPointProperty_19();
  public vtkProperty GetEndPointProperty() {
    long temp = GetEndPointProperty_19();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedEndPointProperty_20();
  public vtkProperty GetSelectedEndPointProperty() {
    long temp = GetSelectedEndPointProperty_20();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetEndPoint2Property_21();
  public vtkProperty GetEndPoint2Property() {
    long temp = GetEndPoint2Property_21();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedEndPoint2Property_22();
  public vtkProperty GetSelectedEndPoint2Property() {
    long temp = GetSelectedEndPoint2Property_22();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLineProperty_23();
  public vtkProperty GetLineProperty() {
    long temp = GetLineProperty_23();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedLineProperty_24();
  public vtkProperty GetSelectedLineProperty() {
    long temp = GetSelectedLineProperty_24();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTolerance_25(int id0);
  public void SetTolerance(int id0)
    { SetTolerance_25(id0); }

  private native int GetToleranceMinValue_26();
  public int GetToleranceMinValue()
    { return GetToleranceMinValue_26(); }

  private native int GetToleranceMaxValue_27();
  public int GetToleranceMaxValue()
    { return GetToleranceMaxValue_27(); }

  private native int GetTolerance_28();
  public int GetTolerance()
    { return GetTolerance_28(); }

  private native void SetResolution_29(int id0);
  public void SetResolution(int id0)
    { SetResolution_29(id0); }

  private native int GetResolution_30();
  public int GetResolution()
    { return GetResolution_30(); }

  private native void GetPolyData_31(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_31(id0); }

  private native void PlaceWidget_32(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_32(id0); }

  private native void BuildRepresentation_33();
  public void BuildRepresentation()
    { BuildRepresentation_33(); }

  private native int ComputeInteractionState_34(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_34(id0,id1,id2); }

  private native void StartWidgetInteraction_35(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_35(id0); }

  private native void WidgetInteraction_36(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_36(id0); }

  private native double[] GetBounds_37();
  public double[] GetBounds()
    { return GetBounds_37(); }

  private native void GetActors_38(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_38(id0); }

  private native void ReleaseGraphicsResources_39(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_39(id0); }

  private native int RenderOpaqueGeometry_40(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_40(id0); }

  private native int RenderTranslucentPolygonalGeometry_41(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_41(id0); }

  private native int HasTranslucentPolygonalGeometry_42();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_42(); }

  private native void SetInteractionState_43(int id0);
  public void SetInteractionState(int id0)
    { SetInteractionState_43(id0); }

  private native int GetInteractionStateMinValue_44();
  public int GetInteractionStateMinValue()
    { return GetInteractionStateMinValue_44(); }

  private native int GetInteractionStateMaxValue_45();
  public int GetInteractionStateMaxValue()
    { return GetInteractionStateMaxValue_45(); }

  private native void SetRepresentationState_46(int id0);
  public void SetRepresentationState(int id0)
    { SetRepresentationState_46(id0); }

  private native int GetRepresentationState_47();
  public int GetRepresentationState()
    { return GetRepresentationState_47(); }

  private native void SetDirectionalLine_48(boolean id0);
  public void SetDirectionalLine(boolean id0)
    { SetDirectionalLine_48(id0); }

  private native boolean GetDirectionalLine_49();
  public boolean GetDirectionalLine()
    { return GetDirectionalLine_49(); }

  private native void DirectionalLineOn_50();
  public void DirectionalLineOn()
    { DirectionalLineOn_50(); }

  private native void DirectionalLineOff_51();
  public void DirectionalLineOff()
    { DirectionalLineOff_51(); }

  private native int GetMTime_52();
  public int GetMTime()
    { return GetMTime_52(); }

  private native void SetRenderer_53(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_53(id0); }

  private native void SetDistanceAnnotationVisibility_54(int id0);
  public void SetDistanceAnnotationVisibility(int id0)
    { SetDistanceAnnotationVisibility_54(id0); }

  private native int GetDistanceAnnotationVisibility_55();
  public int GetDistanceAnnotationVisibility()
    { return GetDistanceAnnotationVisibility_55(); }

  private native void DistanceAnnotationVisibilityOn_56();
  public void DistanceAnnotationVisibilityOn()
    { DistanceAnnotationVisibilityOn_56(); }

  private native void DistanceAnnotationVisibilityOff_57();
  public void DistanceAnnotationVisibilityOff()
    { DistanceAnnotationVisibilityOff_57(); }

  private native void SetDistanceAnnotationFormat_58(String id0);
  public void SetDistanceAnnotationFormat(String id0)
    { SetDistanceAnnotationFormat_58(id0); }

  private native String GetDistanceAnnotationFormat_59();
  public String GetDistanceAnnotationFormat()
    { return GetDistanceAnnotationFormat_59(); }

  private native void SetDistanceAnnotationScale_60(double id0,double id1,double id2);
  public void SetDistanceAnnotationScale(double id0,double id1,double id2)
    { SetDistanceAnnotationScale_60(id0,id1,id2); }

  private native void SetDistanceAnnotationScale_61(double id0[]);
  public void SetDistanceAnnotationScale(double id0[])
    { SetDistanceAnnotationScale_61(id0); }

  private native double[] GetDistanceAnnotationScale_62();
  public double[] GetDistanceAnnotationScale()
    { return GetDistanceAnnotationScale_62(); }

  private native double GetDistance_63();
  public double GetDistance()
    { return GetDistance_63(); }

  private native void SetLineColor_64(double id0,double id1,double id2);
  public void SetLineColor(double id0,double id1,double id2)
    { SetLineColor_64(id0,id1,id2); }

  private native long GetDistanceAnnotationProperty_65();
  public vtkProperty GetDistanceAnnotationProperty() {
    long temp = GetDistanceAnnotationProperty_65();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTextActor_66();
  public vtkFollower GetTextActor() {
    long temp = GetTextActor_66();

    if (temp == 0) return null;
    return (vtkFollower)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetRestrictFlag_67(int id0);
  public void SetRestrictFlag(int id0)
    { SetRestrictFlag_67(id0); }

  private native int GetRestrictFlagMinValue_68();
  public int GetRestrictFlagMinValue()
    { return GetRestrictFlagMinValue_68(); }

  private native int GetRestrictFlagMaxValue_69();
  public int GetRestrictFlagMaxValue()
    { return GetRestrictFlagMaxValue_69(); }

  public vtkLineRepresentation() { super(); }

  public vtkLineRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
